aboutsummaryrefslogtreecommitdiffstats
path: root/gcc-4.4.3/gcc/cgraph.h
diff options
context:
space:
mode:
authorJing Yu <jingyu@google.com>2011-01-30 22:18:29 -0800
committerJing Yu <jingyu@google.com>2011-01-30 22:18:29 -0800
commit4a66e756636cb8364582ea503abd10d76f5b4aa3 (patch)
tree9660204ec085888a0601a6460c967b204a63d5f3 /gcc-4.4.3/gcc/cgraph.h
parentb6be42e837844cce5283f42fcfac31e6d66a277d (diff)
downloadtoolchain_gcc-4a66e756636cb8364582ea503abd10d76f5b4aa3.tar.gz
toolchain_gcc-4a66e756636cb8364582ea503abd10d76f5b4aa3.tar.bz2
toolchain_gcc-4a66e756636cb8364582ea503abd10d76f5b4aa3.zip
Upgrade gcc-4.4.3 for Android toolchain.
- Backport upstream patches to support arm hardfp. - Backport gcc-4.5 patches to support -march=atom. Now it is able to build atom toolchain with glibc from this branch - Develop a bunch of optimizations - Fix a few arm dejagnu failures To-do list: - Support Android/atom - Fix ia32 bootstrap failure Change-Id: I5e10dcd21620d4d8ca984d1d1707a76067e61691
Diffstat (limited to 'gcc-4.4.3/gcc/cgraph.h')
-rw-r--r--gcc-4.4.3/gcc/cgraph.h12
1 files changed, 10 insertions, 2 deletions
diff --git a/gcc-4.4.3/gcc/cgraph.h b/gcc-4.4.3/gcc/cgraph.h
index 2df9d0821..f83ba05b2 100644
--- a/gcc-4.4.3/gcc/cgraph.h
+++ b/gcc-4.4.3/gcc/cgraph.h
@@ -111,8 +111,9 @@ struct cgraph_global_info GTY(())
/* Estimated size of the function after inlining. */
int insns;
- /* Estimated growth after inlining. INT_MIN if not computed. */
- int estimated_growth;
+ /* Estimated average per-callsite growth after inlining all calls to
+ this function. INT_MIN if not computed. */
+ int estimated_average_growth;
/* Set iff the function has been inlined at least once. */
bool inlined;
@@ -176,6 +177,8 @@ struct cgraph_node GTY((chain_next ("%h.next"), chain_prev ("%h.previous")))
/* Set when function must be output - it is externally visible
or its address is taken. */
unsigned needed : 1;
+ /* Set when the address of the function has been taken. */
+ unsigned address_taken : 1;
/* Set when decl is an abstract function pointed to by the
ABSTRACT_DECL_ORIGIN of a reachable function. */
unsigned abstract_and_needed : 1;
@@ -357,12 +360,15 @@ void cgraph_add_new_function (tree, bool);
void dump_vcg_cgraph (FILE *, int, bool);
+bool hot_function_p (struct cgraph_node *);
+
/* In cgraphunit.c */
void cgraph_finalize_function (tree, bool);
void cgraph_mark_if_needed (tree);
void cgraph_finalize_compilation_unit (void);
void cgraph_optimize (void);
void cgraph_mark_needed_node (struct cgraph_node *);
+void cgraph_mark_address_taken (struct cgraph_node *);
void cgraph_mark_reachable_node (struct cgraph_node *);
bool cgraph_inline_p (struct cgraph_edge *, const char **reason);
bool cgraph_preserve_function_body_p (tree);
@@ -536,6 +542,8 @@ void dump_hot_components (FILE *);
void verify_hot_components (void);
bool cgraph_gate_ipa_early_inlining (void);
+void cgraph_remove_pid (struct cgraph_node *);
+
/* Create a new static variable of type TYPE. */
tree add_new_static_var (tree type);